@@ -234,8 +234,8 @@ namespace KDevelop {
      *   a new list as large as newItemCount, and call object.transferData to transfer the data
      *   into the new list. The new size must match the returned newItemCount.
      * - Either call object.apply(), or let it be called automatically by the destructor.
-     * @param increaseFraction By what fraction the list is increased when it needs to. For example the size will be increased by 1/5 if it's 5.
-     * @param rebuildIfInsertionMoreExpensive The structure is rebuilt completely when an insertion needs a moving around of more than rebuildIfInsertionMoreExpensive times
+     * @tparam increaseFraction By what fraction the list is increased when it needs to. For example the size will be increased by 1/5 if it's 5.
+     * @tparam rebuildIfInsertionMoreExpensive The structure is rebuilt completely when an insertion needs a moving around of more than rebuildIfInsertionMoreExpensive times
                                               the count of items needed to be moved in worst case in a fresh tree.
      *                                          After rebuilding the tree, the free space is evenly distributed, and thus insertions require much less moving.
      * */
@@ -274,7 +274,7 @@ namespace KDevelop {
             }
 
             ///Transfers the data into a new item-list. The size of the new item-list must equal newItemCount()
-            void transferData(Data* newItems, uint newCount, int* newCentralFree = 0) {
+            void transferData(Data* newItems, uint newCount, int* newCentralFree = nullptr) {
                 DEBUG_FREEITEM_COUNT
 
                 uint currentRealCount = m_itemCount - countFreeItems(*m_centralFreeItem);
@@ -756,7 +756,7 @@ namespace KDevelop {
             }
 
             ///Transfers the data into a new item-list. The size of the new item-list must equal newItemCount()
-            void transferData(Data* newItems, uint newCount, int* newCentralFree = 0) {
+            void transferData(Data* newItems, uint newCount, int* newCentralFree = nullptr) {
                 DEBUG_FREEITEM_COUNT
                 //We only transfer into a new list when all the free items are used up
 
